# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-22 01:04
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0017_regcode'),
    ]

    operations = [
        migrations.AddField(
            model_name='regcode',
            name='used_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name=b'\xe4\xbd\xbf\xe7\x94\xa8\xe6\x97\xa5\xe6\x9c\x9f'),
        ),
    ]
