# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-22 11:25
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0021_auto_20190422_1555'),
    ]

    operations = [
        migrations.AlterField(
            model_name='regcode',
            name='used_preuser',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='bee_django_crm.PreUser', verbose_name=b'\xe8\xa2\xab\xe8\xb0\x81\xe4\xbd\xbf\xe7\x94\xa8'),
        ),
    ]
