# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-06-29 06:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0024_auto_20190601_1615'),
    ]

    operations = [
        migrations.AddField(
            model_name='contract',
            name='type',
            field=models.IntegerField(choices=[(1, b'\xe6\x99\xae\xe9\x80\x9a\xe5\x90\x88\xe5\x90\x8c'), (2, b'\xe4\xba\xb2\xe5\xad\x90\xe5\x90\x88\xe5\x90\x8c')], default=1, verbose_name=b'\xe5\x90\x88\xe5\x90\x8c\xe7\xb1\xbb\xe5\x9e\x8b'),
        ),
    ]
