# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-22 07:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0019_regcode_used_preuser'),
    ]

    operations = [
        migrations.AddField(
            model_name='regcode',
            name='reg_number',
            field=models.IntegerField(null=True, unique=True),
        ),
    ]
