# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-07-11 09:18
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0025_contract_type'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='source',
            options={'ordering': ['-created_at'], 'permissions': (('view_crm_source', '\u53ef\u4ee5\u67e5\u770b\u6e20\u9053'), ('can_change_source_name', '\u53ef\u4ee5\u4fee\u6539\u6e20\u9053\u540d\u79f0')), 'verbose_name': 'crm\u6e20\u9053'},
        ),
    ]
