# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-28 07:56
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0010_auto_20180823_1851'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='preuserfee',
            options={'ordering': ['-paid_at', '-created_at'], 'permissions': (('view_crm_preuser_fee', '\u53ef\u4ee5\u67e5\u770b\u7528\u6237\u7f34\u8d39'), ('can_check_crm_preuser_fee', '\u53ef\u4ee5\u5ba1\u6838\u7528\u6237\u7f34\u8d39'))},
        ),
    ]
