{% load bee_django_crm_filter %}
<div class="text-center"><h3>小白</h3></div>
<table class="table">
    <thead>
    <tr>
        <th></th>
        <th>意愿</th>
        <th>姓名</th>
        <th>电话</th>
        <th>报名来源</th>
        <th>推荐人</th>
        <th>
            报名时间
        </th>
        <th>联络次数</th>
        <th></th>
    </tr>
    </thead>
    <tbody>
    {% for preUser in preuser_list %}
        <tr>
            <td>{{ forloop.counter }}</td>
            <td>{{ preUser.get_grade }} </td>
            <td>
                <a href="{% url 'bee_django_crm:preuser_detail' preUser.id %}?admin=1">{{ preUser.name }}</a>
            </td>
            <td>{{ preUser.mobile }}</td>
            <td>{{ preUser.source|default:"无" }}</td>
            <td>{{ preUser|get_referral_user_name|default:"无" }}</td>
            <td>
                {{ preUser.created_at|local_datetime|date:"Y-m-d" }}

            </td>
            <td>{{ preUser.id|get_preuser_track_list|length|default:"0" }}</td>

            <td>
                {% if perms.bee_django_crm.delete_preuser %}
                    <a href="#" id="delete_{{ preuser.id }}"
                       data-confirm="{% url "bee_django_crm:preuser_delete" preUser.id %}"
                       onclick="click_del(this)">删除</a>
                {% endif %}
            </td>
        </tr>

    {% endfor %}
    </tbody>
</table>