# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-07-15 05:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0026_auto_20190711_1718'),
    ]

    operations = [
        migrations.AddField(
            model_name='regcode',
            name='course_days',
            field=models.IntegerField(null=True, verbose_name=b'\xe5\x8f\xaf\xe5\xad\xa6\xe4\xb9\xa0\xe8\xaf\xbe\xe7\xa8\x8b\xe5\xa4\xa9\xe6\x95\xb0'),
        ),
    ]
