# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-08 11:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0002_auto_20180517_1758'),
    ]

    operations = [
        migrations.AlterField(
            model_name='preuser',
            name='mobile',
            field=models.CharField(max_length=15, verbose_name=b'\xe7\x94\xb5\xe8\xaf\x9d'),
        ),
    ]
