<form action="{% url 'bee_django_crm:source_list' %}" method="get">
    {{ search_form }}
    <input type="hidden" name="export" id="export">
    {#    <input type="submit" value="查询"/>#}

    <button class="" onclick="click_search()">查询</button>
{#    <button class="" onclick="click_export()">导出</button>#}
</form>
{% block scripts %}
    <script>

    </script>
{% endblock %}