# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-17 09:58
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='applicationquestion',
            options={'ordering': ['order_by'], 'permissions': (('view_crm_application', '\u53ef\u4ee5\u67e5\u770b\u7533\u8bf7\u8868\u95ee\u9898\u5217\u8868\u9875'),), 'verbose_name': 'crm\u7533\u8bf7\u8868\u95ee\u9898'},
        ),
        migrations.AlterModelOptions(
            name='contract',
            options={'ordering': ['-id'], 'permissions': (('view_crm_contract', '\u53ef\u4ee5\u67e5\u770b\u5408\u540c'),), 'verbose_name': 'crm\u5408\u540c'},
        ),
        migrations.AlterModelOptions(
            name='preuser',
            options={'ordering': ['-created_at'], 'permissions': (('can_manage_crm', '\u53ef\u4ee5\u8fdb\u5165crm\u7ba1\u7406\u9875'), ('view_crm_preuser', '\u53ef\u4ee5\u67e5\u770bcrm\u7528\u6237'), ('view_crm_doc', '\u53ef\u4ee5\u67e5\u770b\u5e2e\u52a9\u6587\u6863')), 'verbose_name': 'crm\u9884\u5907\u7528\u6237'},
        ),
        migrations.AlterModelOptions(
            name='preusercontract',
            options={'ordering': ['-paid_at', '-created_at'], 'permissions': (('view_crm_preuser_contract', '\u53ef\u4ee5\u67e5\u770b\u7528\u6237\u7f34\u8d39'),), 'verbose_name': 'crm\u7528\u6237\u7f34\u8d39'},
        ),
        migrations.AlterModelOptions(
            name='source',
            options={'ordering': ['-created_at'], 'permissions': (('view_crm_source', '\u53ef\u4ee5\u67e5\u770b\u6e20\u9053'),), 'verbose_name': 'crm\u6e20\u9053'},
        ),
    ]
