{% extends "bee_django_crm/base.html" %}
{% load static %}
{% load bootstrap3 %}
{% block content %}
    {% include 'bee_django_crm/logo.html' %}
    {% include 'bee_django_crm/nav.html' %}
    <form method="post">
        {% csrf_token %}
        {% bootstrap_form form %}
        {% bootstrap_button '提交' %}
    </form>
{% endblock %}


{% block scripts %}
    <script>
        $(document).ready(function () {
            //时间
            $.datetimepicker.setLocale('ch');
            var $paid_at = $("#id_paid_at");
            var $study_at = $("#id_study_at");
            $paid_at.datetimepicker({
                format: 'Y-m-d',
                timepicker: false,
                scrollMonth: false,
                scrollTime: false,
                scrollInput: false
            });
            $study_at.datetimepicker({
                format: 'Y-m-d',
                timepicker: false,
                scrollMonth: false,
                scrollTime: false,
                scrollInput: false
            });

        });
    </script>
{% endblock %}