# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-07-08 07:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0004_auto_20180622_1603'),
    ]

    operations = [
        migrations.AlterField(
            model_name='poster',
            name='photo',
            field=models.ImageField(null=True, upload_to=b'bee_django_crm/poster_photo'),
        ),
    ]
