{% extends "bee_django_crm/base.html" %}
{% load bee_django_crm_filter %}

{% block content %}
    {% include 'bee_django_crm/logo.html' %}
    {% include 'bee_django_crm/nav.html' %}
    {% include 'bee_django_crm/messages.html' %}
    <div class="text-center"><h3>
        合同管理
    </h3>
    </div>

    <table class="table">
        <thead>
        <tr>
            <th></th>
            <th>学生</th>
            <th>合同名称</th>
            <th></th>
            <th></th>

        </tr>
        </thead>
        <tbody>
        {% for user_contract in preuser_all_contract_list %}
            <tr>
                <td>{{ forloop.counter }}</td>
                <td>{{ user_contract.preuser.name }}</td>
                <td>{{ user_contract.contract.name }}</td>

                <td><a href="{% url 'bee_django_crm:preuser_contract_detail' user_contract.id %}">详情</a></td>
                <td>


                </td>
            </tr>

        {% endfor %}
        </tbody>
    </table>
    {% include 'bee_django_crm/paginator.html' %}
{% endblock %}
{% block scripts %}
    <script>
        function click_check(_this) {
            if (!confirm('确认要执行这个操作？')) {
                return false;
            }
            var url = $(_this).attr('data-confirm');
            $.post(url).done(function (data) {
                alert('审核成功!');
                location.href = data.url;
            });
        }
    </script>
{% endblock %}